# Registration abci

## Description

This module contains the ABCI registration skill for an AEA.

## Behaviours

* `RegistrationBaseBehaviour`

   Register to the next periods.

* `RegistrationBehaviour`

   Register to the next periods.

* `RegistrationStartupBehaviour`

   Register to the next periods.


## Handlers

No Handlers (the skill is purely behavioural).

